==> haskell-hspec-wai-0.10.1-77-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hspec-wai.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hspec-wai
version:              0.10.1
visibility:           public
id:                   hspec-wai-0.10.1-JSUqVIJjVnh3kOsWqPSZM4
key:                  hspec-wai-0.10.1-JSUqVIJjVnh3kOsWqPSZM4
license:              MIT
copyright:
    (c) 2012-2014 Fujimura Daisuke,
    (c) 2014-2018 Simon Hengel

maintainer:
    Fujimura Daisuke <me@fujimuradaisuke.com>,
    Simon Hengel <sol@typeful.net>

author:
    Fujimura Daisuke <me@fujimuradaisuke.com>,
    Simon Hengel <sol@typeful.net>

homepage:             https://github.com/hspec/hspec-wai#readme
synopsis:             Experimental Hspec support for testing WAI applications
description:          Experimental Hspec support for testing WAI applications
category:             Testing
abi:                  e8f494c2fb68b03639f59bc129f9ee70
exposed:              True
exposed-modules:
    Test.Hspec.Wai Test.Hspec.Wai.Internal Test.Hspec.Wai.Matcher
    Test.Hspec.Wai.QuickCheck

hidden-modules:       Test.Hspec.Wai.Util Paths_hspec_wai
import-dirs:          /usr/lib/ghc-8.10.2/site-local/hspec-wai-0.10.1
library-dirs:         /usr/lib/ghc-8.10.2/site-local/hspec-wai-0.10.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/hspec-wai-0.10.1
hs-libraries:         HShspec-wai-0.10.1-JSUqVIJjVnh3kOsWqPSZM4
depends:
    QuickCheck-2.14.1-6VuQ8t46VkzFgMyrtXYB18 base-4.14.1.0
    base-compat-0.11.1-AU7kFoHd9g4AbsEVNqQYmh bytestring-0.10.10.0
    case-insensitive-1.2.1.0-Ffj8eDXeXIuCuPWqXi9P9U
    hspec-core-2.7.2-GTpd8dtsXJKodvcOl4VBf
    hspec-expectations-0.8.2-CCLwm5ba5vg9KKWMNaxh71
    http-types-0.12.3-HewQbENeOxi5DCtQxgY17v text-1.2.3.2
    transformers-0.5.6.2 wai-3.2.2.1-ChbcvF6lxq3J12r9Eez4W8
    wai-extra-3.0.29.2-1FaxyGe7u7p39MIAziFMAZ

haddock-interfaces:   /usr/share/doc/haskell-hspec-wai/html/hspec-wai.haddock
haddock-html:         /usr/share/doc/haskell-hspec-wai/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hspec-wai-0.10.1-78-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hspec-wai.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hspec-wai
version:              0.10.1
visibility:           public
id:                   hspec-wai-0.10.1-95oo5VaLoqa2bzsAYbv0Cp
key:                  hspec-wai-0.10.1-95oo5VaLoqa2bzsAYbv0Cp
license:              MIT
copyright:
    (c) 2012-2014 Fujimura Daisuke,
    (c) 2014-2018 Simon Hengel

maintainer:
    Fujimura Daisuke <me@fujimuradaisuke.com>,
    Simon Hengel <sol@typeful.net>

author:
    Fujimura Daisuke <me@fujimuradaisuke.com>,
    Simon Hengel <sol@typeful.net>

homepage:             https://github.com/hspec/hspec-wai#readme
synopsis:             Experimental Hspec support for testing WAI applications
description:          Experimental Hspec support for testing WAI applications
category:             Testing
abi:                  9c9c316fab69059f719a17b0e5a958fc
exposed:              True
exposed-modules:
    Test.Hspec.Wai Test.Hspec.Wai.Internal Test.Hspec.Wai.Matcher
    Test.Hspec.Wai.QuickCheck

hidden-modules:       Test.Hspec.Wai.Util Paths_hspec_wai
import-dirs:          /usr/lib/ghc-8.10.2/site-local/hspec-wai-0.10.1
library-dirs:         /usr/lib/ghc-8.10.2/site-local/hspec-wai-0.10.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/hspec-wai-0.10.1
hs-libraries:         HShspec-wai-0.10.1-95oo5VaLoqa2bzsAYbv0Cp
depends:
    QuickCheck-2.14.1-8IJVBGyUfKq6HlL6nbvj8S base-4.14.1.0
    base-compat-0.11.1-AU7kFoHd9g4AbsEVNqQYmh bytestring-0.10.10.0
    case-insensitive-1.2.1.0-95m65GDfZzj9YSjKekFqzw
    hspec-core-2.7.2-HLQdLeNMpSm7wSYrR5lDvL
    hspec-expectations-0.8.2-BWmcoUmHH492cuTy3ce35u
    http-types-0.12.3-DWjrPy9akuILlicMHbsVy4 text-1.2.3.2
    transformers-0.5.6.2 wai-3.2.2.1-3VeAR7Fdq5fBEWEzoTSkiH
    wai-extra-3.0.29.2-IRU91uAJPYmDvqPUFuCSoq

haddock-interfaces:   /usr/share/doc/haskell-hspec-wai/html/hspec-wai.haddock
haddock-html:         /usr/share/doc/haskell-hspec-wai/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
